@@ -11,7 +11,7 @@ use Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(extract_image_links);
 
-our $VERSION = '0.15'; # VERSION
+our $VERSION = '0.16'; # VERSION
 
 our %SPEC;
 
@@ -79,12 +79,39 @@ SHARYANTO::HTML::Extract::ImageLinks - Extract image links from HTML document
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 FUNCTIONS
 
 None are exported by default, but they are exportable.
 
+=head1 FUNCTIONS
+
+
+=head2 extract_image_links(%args) -> [status, msg, result, meta]
+
+Extract image links from HTML document.
+
+Either specify either url, html.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<base> => I<str>
+
+base URL for images.
+
+=item * B<html> => I<str>
+
+HTML document to extract from.
+
+=back
+
+Return value:
+
+Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
